@@ -59,6 +59,8 @@ ResultsWindow::ResultsWindow(MaemoBarcodeWindow *parent) :
 
     selectionTimer = new QTimer(this);
     connect(selectionTimer, SIGNAL(timeout()), this, SLOT(selectionTimerExpiry()));
+
+    pluginUpdateCounter = 0;
 }
 
 ResultsWindow::~ResultsWindow()
@@ -79,6 +81,12 @@ void ResultsWindow::setPluginActions(QList<PluginAction *>plugins) {
     }
 
 }
+
+void ResultsWindow::hideEvent(QHideEvent *) {
+    pluginUpdateCounter = 0;
+    addedPlugins.clear(); // clear the plugins from the list
+}
+
 void ResultsWindow::changeEvent(QEvent *e)
 {
     QMainWindow::changeEvent(e);
@@ -98,10 +106,10 @@ void ResultsWindow::processBarcode(QString barcode) {
         ui->lblResults->setText(tr("Results for '%1'").arg(barcode).simplified());
     }
 
-    pluginUpdateCounter = 0;
+    //pluginUpdateCounter = 0;
     //hideMeTimer->stop();
 
-    addedPlugins.clear(); // clear the plugins from the list
+    //addedPlugins.clear(); // clear the plugins from the list
 
     // save the barcode text
     this->barcode_text = QString(barcode);
